@@ -1,9 +1,9 @@
 package Progress::Any::Output::TermProgressBarColor;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-06-20'; # DATE
+our $DATE = '2020-08-15'; # DATE
 our $DIST = 'Progress-Any-Output-TermProgressBarColor'; # DIST
-our $VERSION = '0.247'; # VERSION
+our $VERSION = '0.249'; # VERSION
 
 use 5.010001;
 use strict;
@@ -14,16 +14,14 @@ require Win32::Console::ANSI if $^O =~ /Win/;
 
 $|++;
 
-# patch handle
-my ($ph1, $ph2);
-
 sub _patch {
     my $out = shift;
 
-    return if $ph1;
+    return if $out->{patch_handle1};
+
     require Monkey::Patch::Action;
     if (defined &{"Log::Any::Adapter::Screen::hook_before_log"}) {
-        $ph1 = Monkey::Patch::Action::patch_package(
+        $out->{patch_handle1} = Monkey::Patch::Action::patch_package(
             'Log::Any::Adapter::Screen', 'hook_before_log', 'replace',
             sub {
                 # we install a hook to clean up progress indicator first before
@@ -33,7 +31,7 @@ sub _patch {
             }
         );
     } elsif (defined  &{"Log::ger::Output::Screen::hook_before_log"}) {
-        $ph1 = Monkey::Patch::Action::patch_package(
+        $out->{patch_handle1} = Monkey::Patch::Action::patch_package(
             'Log::ger::Output::Screen', 'hook_before_log', 'replace',
             sub {
                 # we install a hook to clean up progress indicator first before
@@ -45,10 +43,11 @@ sub _patch {
     }
 
     if (defined &{"Log::Any::Adapter::Screen::hook_after_log"}) {
-        $ph2 = Monkey::Patch::Action::patch_package(
+        $out->{patch_handle2} = Monkey::Patch::Action::patch_package(
             'Log::Any::Adapter::Screen', 'hook_after_log', 'replace',
             sub {
                 my ($self, $msg) = @_;
+
                 # make sure we print a newline after logging so progress bar
                 # starts at column 1
                 print { $self->{_fh} } "\n" unless $msg =~ /\R\z/;
@@ -61,7 +60,7 @@ sub _patch {
             }
         );
     } elsif (defined &{"Log::ger::Output::Screen::hook_after_log"}) {
-        $ph2 = Monkey::Patch::Action::patch_package(
+        $out->{patch_handle2} = Monkey::Patch::Action::patch_package(
             'Log::ger::Output::Screen', 'hook_after_log', 'replace',
             sub {
                 my ($ctx, $msg) = @_;
@@ -80,8 +79,9 @@ sub _patch {
 }
 
 sub _unpatch {
-    undef $ph1;
-    undef $ph2;
+    my $self = shift;
+    undef $self->{patch_handle1};
+    undef $self->{patch_handle2};
 }
 
 sub _template_length {
@@ -215,7 +215,8 @@ sub _handle_unknown_conversion {
             (" " x ($bwidth-$self->{_x}-$bfilled));
     }
 
-    my $msg = $args{args}{message};
+    my $msg = $args{args}{'message.alt.output.TermProgressBarColor'} //
+        $args{args}{message};
     if ($conv eq 'B' && defined $msg) {
         if ($msg =~ m!</elspan!) {
             require String::Elide::Parts;
@@ -332,7 +333,7 @@ Progress::Any::Output::TermProgressBarColor - Output progress to terminal as col
 
 =head1 VERSION
 
-This document describes version 0.247 of Progress::Any::Output::TermProgressBarColor (from Perl distribution Progress-Any-Output-TermProgressBarColor), released on 2020-06-20.
+This document describes version 0.249 of Progress::Any::Output::TermProgressBarColor (from Perl distribution Progress-Any-Output-TermProgressBarColor), released on 2020-08-15.
 
 =head1 SYNOPSIS
 
@@ -473,6 +474,26 @@ again before showing.
 Set C<freq> to e.g. -0.1 or -0.05. The default C<freq>, when unset, is -0.5
 which means to update output at most once every 0.5 second.
 
+=head2 How to display a different message for this output?
+
+For example, this output formats message using L<String::Elide::Parts> so inside
+the message, substrings can be tagged for eliding priority:
+
+ <elspan prio=2>Downloading </elspan><elspan prio=3 truncate=middle>http://127.0.0.1:7007/2.mp4 </elspan>37.3M/139.5M
+
+while another output like L<Progress::Any::Output::TermMessage> does not use
+String::Elide::Parts. It should just display the string as:
+
+ Downloading http://127.0.0.1:7007/2.mp4 37.3M/139.5M
+
+In the indicator, you can provide a specific message for this output:
+
+ $progress->update(
+     message => 'Downloading http://127.0.0.1:7007/2.mp4 37.3M/139.5M',
+     'message.alt.output.TermProgressBarColor' => '<elspan prio=2>Downloading </elspan><elspan prio=3 truncate=middle>http://127.0.0.1:7007/2.mp4 </elspan>37.3M/139.5M',
+     ...
+ );
+
 =head1 ENVIRONMENT
 
 =head2 NO_COLOR
